package uk.ac.cf.spring.demo.sports.security;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.core.userdetails.User;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.provisioning.InMemoryUserDetailsManager;
import org.springframework.security.web.SecurityFilterChain;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;

@Configuration
@EnableWebSecurity
public class SecurityConfig {

    public static final String[] ENDPOINTS_WHITELIST = {
            "/css/**",          // Style Files
            "/js/**",           // JS Files
            "/images/**",       // images
            "/",                // root path
            "/match",           // match data path
            "/match/**",
            "/api/**",          // API
            "/html/**",         // static HTML
            "/html/register.html",        // register
            "/html/login.html"  // login
    };

    @Bean
    public SecurityFilterChain securityFilterChain(HttpSecurity http) throws Exception {
        http
                .authorizeHttpRequests(request -> request
                        .requestMatchers(ENDPOINTS_WHITELIST).permitAll() // 允许白名单页面不需要认证
                        .anyRequest().authenticated() // 其他页面需要认证
                )
                .csrf().disable()
//                .formLogin(form -> form
//                        .loginPage("/login").permitAll() // 定义自定义登录页面
//                )
                .formLogin(form -> form
                        .loginPage("/html/login.html").permitAll() // 使用自定义页面
                        .defaultSuccessUrl("/html/matchSchedule.html", true) // 登录成功后跳转
                        .failureUrl("/html/login.html?error=true") // 登录失败后跳转
                )
                .logout().logoutUrl("/logout").logoutSuccessUrl("/"); // 登出配置
        return http.build();
    }


    @Bean
    public UserDetailsService userDetailsService() {
        UserDetails user =
                User.withDefaultPasswordEncoder()
                        .username("user")
                        .password("password")
                        .roles("USER")
                        .build();
        return new InMemoryUserDetailsManager(user);
    }

    @Bean
    public BCryptPasswordEncoder passwordEncoder() {
        return new BCryptPasswordEncoder();
    }
}

