const MATCHES_API_URL = '/match';
// fixed bug
let matches = [];
// 页面加载时自动获取并展示所有比赛
// show all the matches
async function fetchMatches() {
    try {
        const response = await fetch(MATCHES_API_URL);
          // fix why there no data
          matches = await response.json();
        displayMatches(matches);
    } catch (err) {
        console.error('error fetching match data:', err);
    }
}

// 显示比赛数据
// show match data
function displayMatches(matches) {
    const matchesList = document.getElementById('matchesList');
    // 清空已有的比赛数据 clean data
    matchesList.innerHTML = '';
    matches.forEach(match => {
        const matchItem = document.createElement('div');
        matchItem.classList.add('match-item');
        matchItem.innerHTML = `
            <div class="details">
                <p><strong>${match.sport}</strong></p>
                <p>${match.playerAId} vs ${match.playerBId}</p>
                <p class="time">${new Date(match.planTime).toLocaleString()}</p>
            </div>
            <!--  add status css as class    -->
            <div class="status ${getStatusClass(match.status)}">
                ${match.status.charAt(0).toUpperCase() + match.status.slice(1)}
            </div>
        `;
        // add click to detail page
        matchItem.addEventListener('click', function (){
            window.location.href = `/html/matchDetail.html?id=${match.id}`;
        })
        // add
        matchesList.appendChild(matchItem);
    });
}

// 根据比赛状态返回对应的 class 用于样式
// add class for css
function getStatusClass(status) {
    if (status === 'pending') return 'status-pending';
    if (status === 'confirmed') return 'status-confirmed';
    if (status === 'completed') return 'status-completed';
    // this make some problems if no return will nothing add class
    return '';
}

// 过滤比赛
// filter match
document.getElementById('sportSelect').addEventListener(
    'change',
    async function() {
        // console.log(this)
    const selectedSport = this.value;
    const response = await fetch(MATCHES_API_URL);
    const matches = await response.json();
    // 如果选择了某个特定的运动，过滤掉其他的
    const filteredMatches = selectedSport === 'all'
        ? matches
        : matches.filter(match => match.sport === selectedSport);
    displayMatches(filteredMatches);
});
// filter by status
    document.getElementById('statusSelect').addEventListener('change',
        async function (){
        const selectedSport = this.value;
            const response = await fetch(MATCHES_API_URL);
            const matches = await response.json();
            // 如果选择了某个特定的运动，过滤掉其他的
            const filteredMatches = selectedSport === 'all'
                ? matches
                : matches.filter(match => match.status=== selectedSport);
            displayMatches(filteredMatches);
        })
//sort by time
// up
    let normalSortTop = true;
    let sortedMatches;
    document.getElementById('sortTimeBtn').addEventListener('click', function (){
        if (matches.length === 0) {
            console.log('no matches data available for sorting')
            return;
        }
        let sortedMatches = [...matches].sort((a,b) =>{
            const timeA = new Date(a.planTime).getTime();
            const timeB = new Date(b.planTime).getTime();
            return normalSortTop ? timeA - timeB : timeB - timeA;
        })
        normalSortTop = ! normalSortTop;
        displayMatches(sortedMatches);
        }
    )
// 模糊查询功能 search
document.getElementById('searchInput').addEventListener('input', function() {
    const searchQuery = this.value.toLowerCase();

    // 根据 sport, playerAId, playerBId, 和 status 进行模糊查询
    const filteredMatches = matches.filter(match => {
        return (
            match.sport.toLowerCase().includes(searchQuery) ||
            match.playerAId.toString().includes(searchQuery) ||
            match.playerBId.toString().includes(searchQuery) ||
            match.status.toLowerCase().includes(searchQuery)
        );
    });

    displayMatches(filteredMatches);  // 显示匹配的比赛
});
// load page
window.onload = fetchMatches;